@@ -8,7 +8,7 @@ _NORNIR_SETTINGS = {
     "nornir.core": {"num_workers": 20},
 }
 
-PLUGIN_CFG = settings.PLUGINS_CONFIG["nautobot_plugin_nornir"]
+PLUGIN_CFG = settings.PLUGINS_CONFIG.get("nautobot_plugin_nornir", {})
 NORNIR_SETTINGS = PLUGIN_CFG.get("nornir_settings", _NORNIR_SETTINGS)
 
 DEFAULT_DRIVERS_MAPPING = PLUGIN_CFG.get("dispatcher_mapping", _DEFAULT_DRIVERS_MAPPING)
